"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var groupBy_1 = require("./groupBy");
var pipe_1 = require("./pipe");
var array = [
    { a: 1, b: 1 },
    { a: 1, b: 2 },
    { a: 2, b: 1 },
    { a: 1, b: 3 },
];
var expected = {
    1: [
        { a: 1, b: 1 },
        { a: 1, b: 2 },
        { a: 1, b: 3 },
    ],
    2: [{ a: 2, b: 1 }],
};
describe('data first', function () {
    test('groupBy', function () {
        expect((0, groupBy_1.groupBy)(array, function (x) { return x.a; })).toEqual(expected);
    });
    test('groupBy.indexed', function () {
        expect(groupBy_1.groupBy.indexed(array, function (x) { return x.a; })).toEqual(expected);
    });
});
describe('data last', function () {
    test('groupBy', function () {
        expect((0, pipe_1.pipe)(array, (0, groupBy_1.groupBy)(function (x) { return x.a; }))).toEqual(expected);
    });
    test('groupBy.indexed', function () {
        expect((0, pipe_1.pipe)(array, groupBy_1.groupBy.indexed(function (x) { return x.a; }))).toEqual(expected);
    });
});
describe('groupBy typings', function () {
    test('keys should be strictly inferred', function () {
        var actual = (0, groupBy_1.groupBy)(array, function (x) { return x.a; });
        var result = true;
        expect(result).toEqual(true);
    });
    test('keys should be strictly inferred for indexed version', function () {
        var actual = groupBy_1.groupBy.indexed(array, function (x) { return x.a; });
        var result = true;
        expect(result).toEqual(true);
    });
    test('keys should be strictly inferred for data last version', function () {
        var actual = (0, pipe_1.pipe)(array, (0, groupBy_1.groupBy)(function (x) { return x.a; }));
        var result = true;
        expect(result).toEqual(true);
    });
    test('keys of union types should not be directly accessible', function () {
        var _a, _b;
        var myTypes = [{ type: 'right' }];
        var grouped = (0, groupBy_1.groupBy)(myTypes, function (item) { return item.type; });
        // @ts-expect-error we can't access keys unconditionally
        expect(function () { return grouped.wrong.length; }).toThrow();
        // @ts-expect-error other values are not allowed by typings
        expect(grouped.notexists).toBeUndefined();
        expect((_a = grouped.wrong) === null || _a === void 0 ? void 0 : _a.length).toBeUndefined();
        expect((_b = grouped.right) === null || _b === void 0 ? void 0 : _b.length).toBe(1);
    });
});
